betty.dispatch module - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.dispatch module

Provide the Dispatch API.

class betty.dispatch.Dispatcher

  Bases: `ABC`

  Dispatch events to handlers.

  abstract dispatch(target_type: type[Any]) → Callable[[...], Awaitable[Sequence[Any]]]

    Dispatch a single target.

    Parameters:

      target_type (`type`[`typing.Any`])

    Return type:

      `typing.Callable`[`...`, `typing.Awaitable`[`typing.Sequence`[`typing.Any`]]]